@@ -1,11 +1,12 @@
 from concurrent.futures import as_completed, ThreadPoolExecutor
-from src.clients.db import DB
-from src.errors.error_handling import catch_error
+import time
 from typing import Dict, List
-
 import logging
+
 import requests
 import src.config as config
+from src.clients.db import DB
+from src.errors.error_handling import catch_error
 
 
 class API:
@@ -40,6 +41,7 @@ class API:
         if resp.status_code == 402:
             logging.info("refreshing tokens", self.access_token)
             self._refresh()
+            time.sleep(0.1)
             self._request(method, service, endpoint, payload)
         logging.info(f" - REQUEST, {service}, {endpoint}, {resp.status_code}")
         return catch_error(resp)
@@ -55,8 +57,7 @@ class API:
         s = requests.Session()
         s.cookies["refresh_token"] = API.db.refresh_token
         resp = s.get(f"{API.api_url}/auth/refresh")
-        resp.raise_for_status()
-        token = resp.json()
+        token = catch_error(resp, service="auth")
         API.db.access_token = token["access_token"]
         API.db.refresh_token = resp.cookies["refresh_token"]
         return True
