@@ -16,5 +16,5 @@ class NotLoggedIn(CofactorError):
 
 
 class InvalidCredentials(CofactorError):
-    message = "Invalid credentials provided, please try logging again."
+    message = "Invalid or expired credentials provided, please try logging again."
     code = 401
